@@ -12,9 +12,14 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 from __future__ import annotations
-from typing import TYPE_CHECKING
+
+from typing import TYPE_CHECKING, Any
+
 if TYPE_CHECKING:
     from supertokens_python.recipe.emailpassword.interfaces import APIOptions, APIInterface
+
+from supertokens_python.exceptions import raise_bad_input_exception
+
 from .utils import validate_form_fields_or_throw_error
 
 
@@ -22,10 +27,12 @@ async def handle_generate_password_reset_token_api(api_implementation: APIInterf
     if api_implementation.disable_generate_password_reset_token_post:
         return None
     body = await api_options.request.json()
-    form_fields_raw = body['formFields'] if 'formFields' in body else []
+    if body is None:
+        raise_bad_input_exception('Please provide a JSON body')
+    form_fields_raw: Any = body['formFields'] if 'formFields' in body else []
     form_fields = await validate_form_fields_or_throw_error(api_options.config.reset_password_using_token_feature.form_fields_for_generate_token_form,
                                                             form_fields_raw)
-    response = await api_implementation.generate_password_reset_token_post(form_fields, api_options)
+    response = await api_implementation.generate_password_reset_token_post(form_fields, api_options, {})
 
     api_options.response.set_json_content(response.to_json())
 
