@@ -11,14 +11,15 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from supertokens_python.recipe.openid.interfaces import APIInterface, APIOptions
+from supertokens_python.recipe.openid.interfaces import (APIInterface,
+                                                         APIOptions)
 
 
 async def open_id_discovery_configuration_get(api_implementation: APIInterface, api_options: APIOptions):
     if api_implementation.disable_open_id_discovery_configuration_get:
         return None
 
-    result = await api_implementation.open_id_discovery_configuration_get(api_options)
+    result = await api_implementation.open_id_discovery_configuration_get(api_options, {})
     api_options.response.set_header("Access-Control-Allow-Origin", "*")
     api_options.response.set_json_content(result.to_json())
 
