@@ -12,13 +12,15 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 from __future__ import annotations
-from typing import TYPE_CHECKING
+
+from typing import TYPE_CHECKING, Union
 
 from supertokens_python.recipe.thirdparty.utils import find_right_provider
 
 if TYPE_CHECKING:
     from supertokens_python.recipe.thirdparty.interfaces import APIOptions, APIInterface
     from supertokens_python.recipe.thirdparty.provider import Provider
+
 from supertokens_python.exceptions import raise_bad_input_exception
 
 
@@ -31,12 +33,12 @@ async def handle_authorisation_url_api(api_implementation: APIInterface, api_opt
         raise_bad_input_exception(
             'Please provide the thirdPartyId as a GET param')
 
-    provider: Provider = find_right_provider(api_options.providers, third_party_id, None)
+    provider: Union[None, Provider] = find_right_provider(
+        api_options.providers, third_party_id, None)
     if provider is None:
-        raise_bad_input_exception('The third party provider ' + third_party_id + ' seems to be missing from the '
-                                                                                 'backend configs.')
+        raise_bad_input_exception('The third party provider ' + third_party_id + ' seems to be missing from the backend configs.')
 
-    result = await api_implementation.authorisation_url_get(provider, api_options)
+    result = await api_implementation.authorisation_url_get(provider, api_options, {})
     api_options.response.set_json_content(result.to_json())
 
     return api_options.response
